# Status Pages and Status Emails
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/status-pages-and-status-emails#overview)
  * [Accessing the Availability Page in SAP for Me](https://help.sap.com/docs/leanix/ea/status-pages-and-status-emails#accessing-the-availability-page-in-sap-for-me)
  * [Configuring Status Emails](https://help.sap.com/docs/leanix/ea/status-pages-and-status-emails#configuring-status-emails)
  * [Additional Information](https://help.sap.com/docs/leanix/ea/status-pages-and-status-emails#additional-information)


_Stay informed about SAP LeanIX service availability and disruptions, and configure status emails in SAP for Me to receive timely updates on service availability, maintenance, and incidents._
